@@ -10,8 +10,9 @@ from warnings import warn
 
 import h5py
 import numpy as np
-from npstreams import average, itercopy, peek, pmap
 from scipy.ndimage import gaussian_filter
+
+from npstreams import average, itercopy, peek, pmap
 from skued import (azimuthal_average, baseline_dt, combine_masks,
                    electron_wavelength, ialign, mask_from_collection, nfold,
                    powder_calq)
@@ -29,6 +30,7 @@ class DiffractionDataset(h5py.File, metaclass = MetaHDF5Dataset):
 
     # Subclasses can add more experimental parameters like those below
     # The types must be representable by h5py
+    acquisition_date= HDF5ExperimentalParameter('acquisition_date',str,   default = '')       # Acquisition date, no specific format
     energy          = HDF5ExperimentalParameter('energy',          float, default = 90)       # keV
     pump_wavelength = HDF5ExperimentalParameter('pump_wavelength', int,   default = 800)      # nanometers
     fluence         = HDF5ExperimentalParameter('fluence',         float, default = 0)        # milliJoules / centimeters ^ 2
@@ -94,7 +96,7 @@ class DiffractionDataset(h5py.File, metaclass = MetaHDF5Dataset):
             kwargs['libver'] = 'latest'
 
         # H5py will raise an exception if arrays are not contiguous
-        patterns = map(np.ascontiguousarray, iter(patterns))
+        # patterns = map(np.ascontiguousarray, iter(patterns))
 
         if callback is None: 
             callback = lambda _: None
@@ -151,6 +153,8 @@ class DiffractionDataset(h5py.File, metaclass = MetaHDF5Dataset):
                 callback(round(100 * index / np.size(time_points)))
 
         callback(100)
+        
+        # Now that the file exists, we can switch to read/write mode
         kwargs['mode'] = 'r+'
         return cls(filename, **kwargs)
 
